@@ -28,6 +28,9 @@ __all__ = (
     "AccountUsageTypeDef",
     "AliasConfigurationTypeDef",
     "AliasRoutingConfigurationTypeDef",
+    "AllowedPublishersTypeDef",
+    "CodeSigningConfigTypeDef",
+    "CodeSigningPoliciesTypeDef",
     "ConcurrencyTypeDef",
     "DeadLetterConfigTypeDef",
     "DestinationConfigTypeDef",
@@ -51,9 +54,12 @@ __all__ = (
     "VpcConfigResponseTypeDef",
     "AddLayerVersionPermissionResponseTypeDef",
     "AddPermissionResponseTypeDef",
+    "CreateCodeSigningConfigResponseTypeDef",
     "EnvironmentTypeDef",
     "FunctionCodeTypeDef",
     "GetAccountSettingsResponseTypeDef",
+    "GetCodeSigningConfigResponseTypeDef",
+    "GetFunctionCodeSigningConfigResponseTypeDef",
     "GetFunctionConcurrencyResponseTypeDef",
     "GetFunctionResponseTypeDef",
     "GetLayerVersionPolicyResponseTypeDef",
@@ -64,8 +70,10 @@ __all__ = (
     "InvokeAsyncResponseTypeDef",
     "LayerVersionContentInputTypeDef",
     "ListAliasesResponseTypeDef",
+    "ListCodeSigningConfigsResponseTypeDef",
     "ListEventSourceMappingsResponseTypeDef",
     "ListFunctionEventInvokeConfigsResponseTypeDef",
+    "ListFunctionsByCodeSigningConfigResponseTypeDef",
     "ListFunctionsResponseTypeDef",
     "ListLayerVersionsResponseTypeDef",
     "ListLayersResponseTypeDef",
@@ -74,8 +82,10 @@ __all__ = (
     "ListVersionsByFunctionResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PublishLayerVersionResponseTypeDef",
+    "PutFunctionCodeSigningConfigResponseTypeDef",
     "PutProvisionedConcurrencyConfigResponseTypeDef",
     "TracingConfigTypeDef",
+    "UpdateCodeSigningConfigResponseTypeDef",
     "VpcConfigTypeDef",
     "WaiterConfigTypeDef",
 )
@@ -113,6 +123,37 @@ AliasRoutingConfigurationTypeDef = TypedDict(
     "AliasRoutingConfigurationTypeDef", {"AdditionalVersionWeights": Dict[str, float]}, total=False
 )
 
+AllowedPublishersTypeDef = TypedDict(
+    "AllowedPublishersTypeDef", {"SigningProfileVersionArns": List[str]}
+)
+
+_RequiredCodeSigningConfigTypeDef = TypedDict(
+    "_RequiredCodeSigningConfigTypeDef",
+    {
+        "CodeSigningConfigId": str,
+        "CodeSigningConfigArn": str,
+        "AllowedPublishers": "AllowedPublishersTypeDef",
+        "CodeSigningPolicies": "CodeSigningPoliciesTypeDef",
+        "LastModified": str,
+    },
+)
+_OptionalCodeSigningConfigTypeDef = TypedDict(
+    "_OptionalCodeSigningConfigTypeDef", {"Description": str}, total=False
+)
+
+
+class CodeSigningConfigTypeDef(
+    _RequiredCodeSigningConfigTypeDef, _OptionalCodeSigningConfigTypeDef
+):
+    pass
+
+
+CodeSigningPoliciesTypeDef = TypedDict(
+    "CodeSigningPoliciesTypeDef",
+    {"UntrustedArtifactOnDeployment": Literal["Warn", "Enforce"]},
+    total=False,
+)
+
 ConcurrencyTypeDef = TypedDict(
     "ConcurrencyTypeDef", {"ReservedConcurrentExecutions": int}, total=False
 )
@@ -240,6 +281,8 @@ FunctionConfigurationTypeDef = TypedDict(
             "InvalidSecurityGroup",
         ],
         "FileSystemConfigs": List["FileSystemConfigTypeDef"],
+        "SigningProfileVersionArn": str,
+        "SigningJobArn": str,
     },
     total=False,
 )
@@ -256,11 +299,22 @@ FunctionEventInvokeConfigTypeDef = TypedDict(
     total=False,
 )
 
-LayerTypeDef = TypedDict("LayerTypeDef", {"Arn": str, "CodeSize": int}, total=False)
+LayerTypeDef = TypedDict(
+    "LayerTypeDef",
+    {"Arn": str, "CodeSize": int, "SigningProfileVersionArn": str, "SigningJobArn": str},
+    total=False,
+)
 
 LayerVersionContentOutputTypeDef = TypedDict(
     "LayerVersionContentOutputTypeDef",
-    {"Location": str, "CodeSha256": str, "CodeSize": int, "ResponseMetadata": "ResponseMetadata"},
+    {
+        "Location": str,
+        "CodeSha256": str,
+        "CodeSize": int,
+        "SigningProfileVersionArn": str,
+        "SigningJobArn": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -360,6 +414,10 @@ AddPermissionResponseTypeDef = TypedDict(
     "AddPermissionResponseTypeDef", {"Statement": str}, total=False
 )
 
+CreateCodeSigningConfigResponseTypeDef = TypedDict(
+    "CreateCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
+)
+
 EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str]}, total=False)
 
 FunctionCodeTypeDef = TypedDict(
@@ -374,6 +432,15 @@ GetAccountSettingsResponseTypeDef = TypedDict(
     total=False,
 )
 
+GetCodeSigningConfigResponseTypeDef = TypedDict(
+    "GetCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
+)
+
+GetFunctionCodeSigningConfigResponseTypeDef = TypedDict(
+    "GetFunctionCodeSigningConfigResponseTypeDef",
+    {"CodeSigningConfigArn": str, "FunctionName": str},
+)
+
 GetFunctionConcurrencyResponseTypeDef = TypedDict(
     "GetFunctionConcurrencyResponseTypeDef", {"ReservedConcurrentExecutions": int}, total=False
 )
@@ -477,6 +544,12 @@ ListAliasesResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListCodeSigningConfigsResponseTypeDef = TypedDict(
+    "ListCodeSigningConfigsResponseTypeDef",
+    {"NextMarker": str, "CodeSigningConfigs": List["CodeSigningConfigTypeDef"]},
+    total=False,
+)
+
 ListEventSourceMappingsResponseTypeDef = TypedDict(
     "ListEventSourceMappingsResponseTypeDef",
     {"NextMarker": str, "EventSourceMappings": List["EventSourceMappingConfigurationTypeDef"]},
@@ -489,6 +562,12 @@ ListFunctionEventInvokeConfigsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListFunctionsByCodeSigningConfigResponseTypeDef = TypedDict(
+    "ListFunctionsByCodeSigningConfigResponseTypeDef",
+    {"NextMarker": str, "FunctionArns": List[str]},
+    total=False,
+)
+
 ListFunctionsResponseTypeDef = TypedDict(
     "ListFunctionsResponseTypeDef",
     {"NextMarker": str, "Functions": List["FunctionConfigurationTypeDef"]},
@@ -571,6 +650,11 @@ PublishLayerVersionResponseTypeDef = TypedDict(
     total=False,
 )
 
+PutFunctionCodeSigningConfigResponseTypeDef = TypedDict(
+    "PutFunctionCodeSigningConfigResponseTypeDef",
+    {"CodeSigningConfigArn": str, "FunctionName": str},
+)
+
 PutProvisionedConcurrencyConfigResponseTypeDef = TypedDict(
     "PutProvisionedConcurrencyConfigResponseTypeDef",
     {
@@ -588,6 +672,10 @@ TracingConfigTypeDef = TypedDict(
     "TracingConfigTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
 )
 
+UpdateCodeSigningConfigResponseTypeDef = TypedDict(
+    "UpdateCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
+)
+
 VpcConfigTypeDef = TypedDict(
     "VpcConfigTypeDef", {"SubnetIds": List[str], "SecurityGroupIds": List[str]}, total=False
 )
